===========================================
Binary data structures (un-)Packing library
===========================================

:HomePage:  https://github.com/avalentino/bpack
:Author:    Antonio Valentino
:Contact:   antonio.valentino@tiscali.it
:Copyright: 2020-2021, Antonio Valentino <antonio.valentino@tiscali.it>
:Version:   |release|


.. toctree::
   :maxdepth: 2

   overview
   installation
   userguide
   api/bpack
   development
   license
   release_notes
